@@ -1,11 +1,10 @@
-__all__ = ["VERSION", "PACKAGE", "WEBSITE", "ICON_PATH", "PIXMAP_PATH", "UI_PATH", "PKGDATA_DIR", "BIN_DIR"]
+__all__ = ["VERSION", "PACKAGE", "WEBSITE", "ICON_PATH", "PIXMAP_PATH", "UI_PATH", "BIN_DIR"]
 
-VERSION = "2.2.1"
+VERSION = "2.3.1"
 PACKAGE = "blueman"
 WEBSITE = "https://github.com/blueman-project/blueman"
 PREFIX = "/usr"
 BIN_DIR = "/usr/bin"
-PKGDATA_DIR = "/usr/share/blueman"
 LOCALEDIR = "/usr/share/locale"
 ICON_PATH = "/usr/share/icons"
 PIXMAP_PATH = "/usr/share/blueman/pixmaps"
